@@ -234,6 +234,8 @@ private:
     int                  m_groupsSize;
 
     std::vector<int>     m_layers;           /// Stores layer numbers used by the item.
+
+    BOX2I                m_bbox;             /// Cached inserted Bbox for faster removals.
 };
 
 
@@ -326,6 +328,8 @@ void VIEW::Add( VIEW_ITEM* aItem, int aDrawPriority )
 
     aItem->m_viewPrivData->m_view = this;
     aItem->m_viewPrivData->m_drawPriority = aDrawPriority;
+    const BOX2I bbox = aItem->ViewBBox();
+    aItem->m_viewPrivData->m_bbox = bbox;
 
     aItem->ViewGetLayers( layers, layers_count );
     aItem->viewPrivData()->saveLayers( layers, layers_count );
@@ -338,7 +342,7 @@ void VIEW::Add( VIEW_ITEM* aItem, int aDrawPriority )
                       continue, wxS( "Invalid layer" ) );
 
         VIEW_LAYER& l = m_layers[layers[i]];
-        l.items->Insert( aItem );
+        l.items->Insert( aItem, bbox );
         MarkTargetDirty( l.target );
     }
 
@@ -362,11 +366,12 @@ void VIEW::Remove( VIEW_ITEM* aItem )
 
         int layers[VIEW::VIEW_MAX_LAYERS], layers_count;
         aItem->m_viewPrivData->getLayers( layers, layers_count );
+        const BOX2I* bbox = &aItem->m_viewPrivData->m_bbox;
 
         for( int i = 0; i < layers_count; ++i )
         {
             VIEW_LAYER& l = m_layers[layers[i]];
-            l.items->Remove( aItem );
+            l.items->Remove( aItem, bbox );
             MarkTargetDirty( l.target );
 
             // Clear the GAL cache
@@ -394,35 +399,19 @@ void VIEW::SetRequired( int aLayerId, int aRequiredId, bool aRequired )
 }
 
 
-// stupid C++... python lambda would do this in one line
-template <class CONTAINER>
-struct QUERY_VISITOR
-{
-    typedef typename CONTAINER::value_type item_type;
-
-    QUERY_VISITOR( CONTAINER& aCont, int aLayer ) :
-        m_cont( aCont ), m_layer( aLayer )
-    {
-    }
-
-    bool operator()( VIEW_ITEM* aItem )
-    {
-        if( aItem->viewPrivData()->GetFlags() & VISIBLE )
-            m_cont.push_back( VIEW::LAYER_ITEM_PAIR( aItem, m_layer ) );
-
-        return true;
-    }
-
-    CONTAINER&  m_cont;
-    int         m_layer;
-};
-
-
 int VIEW::Query( const BOX2I& aRect, std::vector<LAYER_ITEM_PAIR>& aResult ) const
 {
     if( m_orderedLayers.empty() )
         return 0;
 
+    int  layer = UNDEFINED_LAYER;
+    auto visitor =
+            [&]( VIEW_ITEM* item ) -> bool
+            {
+                aResult.push_back( VIEW::LAYER_ITEM_PAIR( item, layer ) );
+                return true;
+            };
+
     std::vector<VIEW_LAYER*>::const_reverse_iterator i;
 
     // execute queries in reverse direction, so that items that are on the top of
@@ -433,7 +422,7 @@ int VIEW::Query( const BOX2I& aRect, std::vector<LAYER_ITEM_PAIR>& aResult ) con
         if( ( *i )->displayOnly || !( *i )->visible )
             continue;
 
-        QUERY_VISITOR<std::vector<LAYER_ITEM_PAIR> > visitor( aResult, ( *i )->id );
+        layer = ( *i )->id;
         ( *i )->items->Query( aRect, visitor );
     }
 
@@ -441,6 +430,22 @@ int VIEW::Query( const BOX2I& aRect, std::vector<LAYER_ITEM_PAIR>& aResult ) con
 }
 
 
+void VIEW::Query( const BOX2I& aRect, const std::function<bool( VIEW_ITEM* )>& aFunc ) const
+{
+    if( m_orderedLayers.empty() )
+        return;
+
+    for( const auto& i : m_orderedLayers )
+    {
+        // ignore layers that do not contain actual items (i.e. the selection box, menus, floats)
+        if( i->displayOnly || !i->visible )
+            continue;
+
+        i->items->Query( aRect, aFunc );
+    }
+}
+
+
 VECTOR2D VIEW::ToWorld( const VECTOR2D& aCoord, bool aAbsolute ) const
 {
     const MATRIX3x3D& matrix = m_gal->GetScreenWorldMatrix();
@@ -617,6 +622,9 @@ void VIEW::SetCenter( const VECTOR2D& aCenter, const std::vector<BOX2D>& obscuri
     BOX2I bbox = unobscuredPoly.BBox();
     int   step = std::min( bbox.GetWidth(), bbox.GetHeight() ) / 10;
 
+    if( step < 20 )
+        step = 20;
+
     while( !unobscuredPoly.IsEmpty() )
     {
         unobscuredCenter = unobscuredPoly.BBox().Centre();
@@ -1327,12 +1335,17 @@ void VIEW::updateBbox( VIEW_ITEM* aItem )
     int layers[VIEW_MAX_LAYERS], layers_count;
 
     aItem->ViewGetLayers( layers, layers_count );
+    wxASSERT( aItem->m_viewPrivData ); //must have a viewPrivData
+
+    const BOX2I  new_bbox = aItem->ViewBBox();
+    const BOX2I* old_bbox = &aItem->m_viewPrivData->m_bbox;
+    aItem->m_viewPrivData->m_bbox = new_bbox;
 
     for( int i = 0; i < layers_count; ++i )
     {
         VIEW_LAYER& l = m_layers[layers[i]];
-        l.items->Remove( aItem );
-        l.items->Insert( aItem );
+        l.items->Remove( aItem, old_bbox );
+        l.items->Insert( aItem, new_bbox );
         MarkTargetDirty( l.target );
     }
 }
@@ -1348,11 +1361,12 @@ void VIEW::updateLayers( VIEW_ITEM* aItem )
 
     // Remove the item from previous layer set
     viewData->getLayers( layers, layers_count );
+    const BOX2I* old_bbox = &aItem->m_viewPrivData->m_bbox;
 
     for( int i = 0; i < layers_count; ++i )
     {
         VIEW_LAYER& l = m_layers[layers[i]];
-        l.items->Remove( aItem );
+        l.items->Remove( aItem, old_bbox );
         MarkTargetDirty( l.target );
 
         if( IsCached( l.id ) )
@@ -1368,6 +1382,9 @@ void VIEW::updateLayers( VIEW_ITEM* aItem )
         }
     }
 
+    const BOX2I new_bbox = aItem->ViewBBox();
+    aItem->m_viewPrivData->m_bbox = new_bbox;
+
     // Add the item to new layer set
     aItem->ViewGetLayers( layers, layers_count );
     viewData->saveLayers( layers, layers_count );
@@ -1375,7 +1392,7 @@ void VIEW::updateLayers( VIEW_ITEM* aItem )
     for( int i = 0; i < layers_count; i++ )
     {
         VIEW_LAYER& l = m_layers[layers[i]];
-        l.items->Insert( aItem );
+        l.items->Insert( aItem, new_bbox );
         MarkTargetDirty( l.target );
     }
 }
@@ -1463,6 +1480,9 @@ void VIEW::UpdateItems()
         // and re-insert items from scratch
         for( VIEW_ITEM* item : allItems )
         {
+            const BOX2I bbox = item->ViewBBox();
+            item->m_viewPrivData->m_bbox = bbox;
+
             item->ViewGetLayers( layers, layers_count );
             item->viewPrivData()->saveLayers( layers, layers_count );
 
@@ -1471,7 +1491,7 @@ void VIEW::UpdateItems()
                 wxCHECK2_MSG( layers[i] >= 0 && static_cast<unsigned>( layers[i] ) < m_layers.size(),
                         continue, wxS( "Invalid layer" ) );
                 VIEW_LAYER& l = m_layers[layers[i]];
-                l.items->Insert( item );
+                l.items->Insert( item, bbox );
                 MarkTargetDirty( l.target );
             }
 
