@@ -1214,6 +1214,7 @@ void SIMULATOR_FRAME_UI::onMeasurementsGridCellChanged( wxGridEvent& aEvent )
     if( col == COL_MEASUREMENT )
     {
         UpdateMeasurement( row );
+        updateMeasurementsFromGrid();
         OnModify();
     }
     else
@@ -1365,6 +1366,8 @@ void SIMULATOR_FRAME_UI::UpdateMeasurement( int aRow )
 
         fmt.UpdateUnits( units );
         SetMeasureFormat( aRow, fmt );
+
+        updateMeasurementsFromGrid();
     }
 
     if( m_simulatorFrame->SimFinished() )
@@ -1493,9 +1496,9 @@ void SIMULATOR_FRAME_UI::AddMeasurement( const wxString& aCmd )
     }
 
     m_measurementsGrid->SetCellValue( row, COL_MEASUREMENT, aCmd );
-    SetMeasureFormat( row, { 2, wxS( "~V" ) } );
 
     UpdateMeasurement( row );
+    updateMeasurementsFromGrid();
     OnModify();
 
     // Always leave at least one empty row for type-in:
@@ -1718,46 +1721,24 @@ void SIMULATOR_FRAME_UI::updateTrace( const wxString& aVectorName, int aTraceTyp
         wxFAIL_MSG( wxT( "Unhandled plot type" ) );
     }
 
-    // If we did a two-source DC analysis, we need to split the resulting vector and add traces
-    // for each input step
     SPICE_DC_PARAMS source1, source2;
+    int             sweepCount = 1;
+    size_t          sweepSize = std::numeric_limits<size_t>::max();
 
     if( simType == ST_DC
             && circuitModel()->ParseDCCommand( aPlotTab->GetSimCommand(), &source1, &source2 )
             && !source2.m_source.IsEmpty() )
     {
-        // Source 1 is the inner loop, so lets add traces for each Source 2 (outer loop) step
-        SPICE_VALUE v = source2.m_vstart;
+        SPICE_VALUE v = ( source2.m_vend - source2.m_vstart ) / source2.m_vincrement;
 
-        size_t offset = 0;
-        size_t outer = ( size_t )( ( source2.m_vend - v ) / source2.m_vincrement ).ToDouble();
-        size_t inner = aDataX->size() / ( outer + 1 );
-
-        wxASSERT( aDataX->size() % ( outer + 1 ) == 0 );
-
-        for( size_t idx = 0; idx <= outer; idx++ )
-        {
-            if( TRACE* trace = aPlotTab->GetOrAddTrace( aVectorName, aTraceType ) )
-            {
-                if( data_y.size() >= size )
-                {
-                    std::vector<double> sub_x( aDataX->begin() + offset,
-                                               aDataX->begin() + offset + inner );
-                    std::vector<double> sub_y( data_y.begin() + offset,
-                                               data_y.begin() + offset + inner );
-
-                    aPlotTab->SetTraceData( trace, sub_x, sub_y );
-                }
-            }
-
-            v = v + source2.m_vincrement;
-            offset += inner;
-        }
+        sweepCount = KiROUND( v.ToDouble() ) + 1;
+        sweepSize = aDataX->size() / sweepCount;
     }
-    else if( TRACE* trace = aPlotTab->GetOrAddTrace( aVectorName, aTraceType ) )
+
+    if( TRACE* trace = aPlotTab->GetOrAddTrace( aVectorName, aTraceType ) )
     {
         if( data_y.size() >= size )
-            aPlotTab->SetTraceData( trace, *aDataX, data_y );
+            aPlotTab->SetTraceData( trace, *aDataX, data_y, sweepCount, sweepSize );
     }
 }
 
@@ -2101,6 +2082,29 @@ bool SIMULATOR_FRAME_UI::loadJsonWorkbook( const wxString& aPath )
 
         return false;
     }
+    catch( nlohmann::json::type_error& error )
+    {
+        wxLogTrace( traceSettings, wxT( "Json type error reading %s: %s" ), aPath, error.what() );
+
+        return false;
+    }
+    catch( nlohmann::json::invalid_iterator& error )
+    {
+        wxLogTrace( traceSettings, wxT( "Json invalid_iterator error reading %s: %s" ), aPath, error.what() );
+
+        return false;
+    }
+    catch( nlohmann::json::out_of_range& error )
+    {
+        wxLogTrace( traceSettings, wxT( "Json out_of_range error reading %s: %s" ), aPath, error.what() );
+
+        return false;
+    }
+    catch( ... )
+    {
+        wxLogTrace( traceSettings, wxT( "Error reading %s" ), aPath );
+        return false;
+    }
 
     return true;
 }
@@ -2160,10 +2164,20 @@ bool SIMULATOR_FRAME_UI::SaveWorkbook( const wxString& aPath )
             auto findSignalName =
                     [&]( const wxString& aVectorName ) -> wxString
                     {
+                        wxString vectorName;
+                        wxString suffix;
+
+                        if( aVectorName.EndsWith( _( " (phase)" ) ) )
+                            suffix = _( " (phase)" );
+                        else if( aVectorName.EndsWith( _( " (gain)" ) ) )
+                            suffix = _( " (gain)" );
+
+                        vectorName = aVectorName.Left( aVectorName.Length() - suffix.Length() );
+
                         for( const auto& [ id, signal ] : m_userDefinedSignals )
                         {
-                            if( aVectorName == vectorNameFromSignalId( id ) )
-                                return signal;
+                            if( vectorName == vectorNameFromSignalId( id ) )
+                                return signal + suffix;
                         }
 
                         return aVectorName;
@@ -2173,7 +2187,7 @@ bool SIMULATOR_FRAME_UI::SaveWorkbook( const wxString& aPath )
             {
                 nlohmann::json trace_js = nlohmann::json(
                             { { "trace_type", (int) trace->GetType() },
-                              { "signal",     findSignalName( trace->GetName() ) },
+                              { "signal",     findSignalName( trace->GetDisplayName() ) },
                               { "color",      COLOR4D( trace->GetTraceColour() ).ToCSSString() } } );
 
                 if( CURSOR* cursor = trace->GetCursor( 1 ) )
@@ -2386,7 +2400,7 @@ void SIMULATOR_FRAME_UI::updateMeasurementsFromGrid()
 
 void SIMULATOR_FRAME_UI::onPlotChanging( wxAuiNotebookEvent& event )
 {
-    updateMeasurementsFromGrid();
+    m_measurementsGrid->ClearRows();
 
     event.Skip();
 }
@@ -2478,23 +2492,43 @@ void SIMULATOR_FRAME_UI::updatePlotCursors()
     auto getUnitsY =
             [&]( TRACE* aTrace ) -> wxString
             {
-                if( ( aTrace->GetType() & SPT_AC_PHASE ) || ( aTrace->GetType() & SPT_CURRENT ) )
-                    return plotTab->GetUnitsY2();
-                else if( aTrace->GetType() & SPT_POWER )
-                    return plotTab->GetUnitsY3();
+                if( plotTab->GetSimType() == ST_AC )
+                {
+                    if( aTrace->GetType() & SPT_AC_PHASE )
+                        return plotTab->GetUnitsY2();
+                    else
+                        return plotTab->GetUnitsY1();
+                }
                 else
-                    return plotTab->GetUnitsY1();
+                {
+                    if( aTrace->GetType() & SPT_POWER )
+                        return plotTab->GetUnitsY3();
+                    else if( aTrace->GetType() & SPT_CURRENT )
+                        return plotTab->GetUnitsY2();
+                    else
+                        return plotTab->GetUnitsY1();
+                }
             };
 
     auto getNameY =
             [&]( TRACE* aTrace ) -> wxString
             {
-                if( ( aTrace->GetType() & SPT_AC_PHASE ) || ( aTrace->GetType() & SPT_CURRENT ) )
-                    return plotTab->GetLabelY2();
-                else if( aTrace->GetType() & SPT_POWER )
-                    return plotTab->GetLabelY3();
+                if( plotTab->GetSimType() == ST_AC )
+                {
+                    if( aTrace->GetType() & SPT_AC_PHASE )
+                        return plotTab->GetLabelY2();
+                    else
+                        return plotTab->GetLabelY1();
+                }
                 else
-                    return plotTab->GetLabelY1();
+                {
+                    if( aTrace->GetType() & SPT_POWER )
+                        return plotTab->GetLabelY3();
+                    else if( aTrace->GetType() & SPT_CURRENT )
+                        return plotTab->GetLabelY2();
+                    else
+                        return plotTab->GetLabelY1();
+                }
             };
 
     auto formatValue =
@@ -2660,7 +2694,10 @@ void SIMULATOR_FRAME_UI::OnSimRefresh( bool aFinal )
     wxString msg;
 
     if( aFinal )
+    {
         applyUserDefinedSignals();
+        updateSignalsGrid();
+    }
 
     // If there are any signals plotted, update them
     if( SIM_TAB::IsPlottable( simType ) )
