@@ -29,6 +29,7 @@
 #include <confirm.h>
 #include <core/arraydim.h>
 #include <core/thread_pool.h>
+#include <dialog_HTML_reporter_base.h>
 #include <gestfich.h>
 #include <pcb_edit_frame.h>
 #include <board_design_settings.h>
@@ -67,6 +68,8 @@
 #include "footprint_info_impl.h"
 #include <board_commit.h>
 #include <zone_filler.h>
+#include <widgets/filedlg_import_non_kicad.h>
+#include <widgets/wx_html_report_box.h>
 #include <wx_filename.h>  // For ::ResolvePossibleSymlinks()
 
 #include <kiplatform/io.h>
@@ -169,15 +172,25 @@ bool AskLoadBoardFileName( PCB_EDIT_FRAME* aParent, wxString* aFileName, int aCt
         // leave name empty
     }
 
+    bool kicadFormat = ( aCtl & KICTL_KICAD_ONLY );
+
     wxFileDialog dlg( aParent,
-                      ( aCtl & KICTL_KICAD_ONLY ) ? _( "Open Board File" )
-                                                  : _( "Import Non KiCad Board File" ),
+                      kicadFormat ? _( "Open Board File" ) : _( "Import Non KiCad Board File" ),
                       path, name, fileFiltersStr, wxFD_OPEN | wxFD_FILE_MUST_EXIST );
 
+    FILEDLG_IMPORT_NON_KICAD importOptions( aParent->config()->m_System.show_import_issues );
+
+    if( !kicadFormat )
+        dlg.SetCustomizeHook( importOptions );
+
     if( dlg.ShowModal() == wxID_OK )
     {
         *aFileName = dlg.GetPath();
         aParent->SetMruPath( wxFileName( dlg.GetPath() ).GetPath() );
+
+        if( !kicadFormat )
+            aParent->config()->m_System.show_import_issues = importOptions.GetShowIssues();
+
         return true;
     }
     else
@@ -645,6 +658,7 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
             CheckForAutoSaveFile( fullFileName );
         }
 
+        DIALOG_HTML_REPORTER errorReporter( this );
         bool failedLoad = false;
 
         try
@@ -681,6 +695,10 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
             // measure the time to load a BOARD.
             int64_t startTime = GetRunningMicroSecs();
 #endif
+            if( config()->m_System.show_import_issues )
+                pi->SetReporter( errorReporter.m_Reporter );
+            else
+                pi->SetReporter( &NULL_REPORTER::GetInstance() );
 
             pi->SetProgressReporter( &progressReporter );
             loadedBoard = pi->LoadBoard( fullFileName, nullptr, &props, &Prj() );
@@ -731,6 +749,12 @@ bool PCB_EDIT_FRAME::OpenProjectFiles( const std::vector<wxString>& aFileSet, in
         // compiled.
         Raise();
 
+        if( errorReporter.m_Reporter->HasMessage() )
+        {
+            errorReporter.m_Reporter->Flush(); // Build HTML messages
+            errorReporter.ShowModal();
+        }
+
         // Skip (possibly expensive) connectivity build here; we build it below after load
         SetBoard( loadedBoard, false, &progressReporter );
 
