@@ -537,7 +537,9 @@ int PNS_PCBNEW_RULE_RESOLVER::Clearance( const PNS::ITEM* aA, const PNS::ITEM* a
                     rv = constraint.m_Value.Min();
             }
         }
-        else if( isCopper( aA ) && ( !aB || isCopper( aB ) ) )
+
+        // No 'else'; plated holes get both HOLE_CLEARANCE and CLEARANCE
+        if( isCopper( aA ) && ( !aB || isCopper( aB ) ) )
         {
             if( QueryConstraint( PNS::CONSTRAINT_TYPE::CT_CLEARANCE, aA, aB, layer, &constraint ) )
             {
@@ -656,13 +658,21 @@ bool PNS_KICAD_IFACE_BASE::ImportSizes( PNS::SIZES_SETTINGS& aSizes, PNS::ITEM*
     aSizes.SetMinClearance( bds.m_MinClearance );
     aSizes.SetClearanceSource( _( "board minimum clearance" ) );
 
-    if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_CLEARANCE, aStartItem, nullptr,
-                                         m_startLayer, &constraint ) )
+    if( aStartItem )
     {
-        if( constraint.m_Value.Min() > bds.m_MinClearance )
+        PNS::SEGMENT dummyTrack;
+        dummyTrack.SetEnds( aStartItem->Anchor( 0 ), aStartItem->Anchor( 0 ) );
+        dummyTrack.SetLayer( ToLAYER_ID( m_startLayer ) );
+        dummyTrack.SetNet( static_cast<NETINFO_ITEM*>( aStartItem->Net() ) );
+
+        if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_CLEARANCE, &dummyTrack,
+                                             nullptr, m_startLayer, &constraint ) )
         {
-            aSizes.SetClearance( constraint.m_Value.Min() );
-            aSizes.SetClearanceSource( constraint.m_RuleName );
+            if( constraint.m_Value.Min() >= bds.m_MinClearance )
+            {
+                aSizes.SetClearance( constraint.m_Value.Min() );
+                aSizes.SetClearanceSource( constraint.m_RuleName );
+            }
         }
     }
 
@@ -680,7 +690,12 @@ bool PNS_KICAD_IFACE_BASE::ImportSizes( PNS::SIZES_SETTINGS& aSizes, PNS::ITEM*
 
     if( !found && bds.UseNetClassTrack() && aStartItem )
     {
-        if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_WIDTH, aStartItem, nullptr,
+        PNS::SEGMENT dummyTrack;
+        dummyTrack.SetEnds( aStartItem->Anchor( 0 ), aStartItem->Anchor( 0 ) );
+        dummyTrack.SetLayer( ToLAYER_ID( m_startLayer ) );
+        dummyTrack.SetNet( static_cast<NETINFO_ITEM*>( aStartItem->Net() ) );
+
+        if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_WIDTH, &dummyTrack, nullptr,
                                              m_startLayer, &constraint ) )
         {
             trackWidth = std::max( trackWidth, constraint.m_Value.Opt() );
@@ -755,8 +770,21 @@ bool PNS_KICAD_IFACE_BASE::ImportSizes( PNS::SIZES_SETTINGS& aSizes, PNS::ITEM*
     // Next, pick up gap from netclass, and width also if we didn't get a starting width above
     if( bds.UseNetClassDiffPair() && aStartItem )
     {
-        if( !found && m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_WIDTH, aStartItem,
-                                                       nullptr, m_startLayer, &constraint ) )
+        PNS::NET_HANDLE coupledNet = m_ruleResolver->DpCoupledNet( aStartItem->Net() );
+
+        PNS::SEGMENT dummyTrack;
+        dummyTrack.SetEnds( aStartItem->Anchor( 0 ), aStartItem->Anchor( 0 ) );
+        dummyTrack.SetLayer( ToLAYER_ID( m_startLayer ) );
+        dummyTrack.SetNet( static_cast<NETINFO_ITEM*>( aStartItem->Net() ) );
+
+        PNS::SEGMENT coupledTrack;
+        dummyTrack.SetEnds( aStartItem->Anchor( 0 ), aStartItem->Anchor( 0 ) );
+        dummyTrack.SetLayer( ToLAYER_ID( m_startLayer ) );
+        dummyTrack.SetNet( static_cast<NETINFO_ITEM*>( coupledNet ) );
+
+        if( !found
+            && m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_WIDTH, &dummyTrack,
+                                                &coupledTrack, m_startLayer, &constraint ) )
         {
             diffPairWidth = std::max( diffPairWidth, constraint.m_Value.Opt() );
 
@@ -764,8 +792,8 @@ bool PNS_KICAD_IFACE_BASE::ImportSizes( PNS::SIZES_SETTINGS& aSizes, PNS::ITEM*
                 aSizes.SetDiffPairWidthSource( constraint.m_RuleName );
         }
 
-        if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_DIFF_PAIR_GAP, aStartItem,
-                                             nullptr, m_startLayer, &constraint ) )
+        if( m_ruleResolver->QueryConstraint( PNS::CONSTRAINT_TYPE::CT_DIFF_PAIR_GAP, &dummyTrack,
+                                             &coupledTrack, m_startLayer, &constraint ) )
         {
             diffPairGap = std::max( diffPairGap, constraint.m_Value.Opt() );
             diffPairViaGap = std::max( diffPairViaGap, constraint.m_Value.Opt() );
@@ -1352,9 +1380,14 @@ bool PNS_KICAD_IFACE_BASE::syncGraphicalItem( PNS::NODE* aWorld, PCB_SHAPE* aIte
             std::unique_ptr<PNS::SOLID> solid = std::make_unique<PNS::SOLID>();
 
             if( aItem->GetLayer() == Edge_Cuts || aItem->GetLayer() == Margin )
+            {
                 solid->SetLayers( LAYER_RANGE( F_Cu, B_Cu ) );
+                solid->SetRoutable( false );
+            }
             else
+            {
                 solid->SetLayer( aItem->GetLayer() );
+            }
 
             if( aItem->GetLayer() == Edge_Cuts )
             {
